# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

## [2.0.0-a2](https://github.com/pmatias/python-acquia-cloud-2/compare/0.0.1-alpha1...2.0.0-a2) - 2018-05-09

### Merged

- Switch super() to self that was missed [`#4`](https://github.com/pmatias/python-acquia-cloud-2/pull/4)

### Commits

- Small release to get the documents in place for Pypi [`a40dc22`](https://github.com/pmatias/python-acquia-cloud-2/commit/a40dc22176af2b643b2c6332254258daca345881)
- Prepare for proper 2.0.0-alpha1 release, the previous tag was just wrong. [`fe6a894`](https://github.com/pmatias/python-acquia-cloud-2/commit/fe6a89496a64810373fe870b680ab7385bca9f18)
- Fixing indentation to make flake8 a bit merrier. [`1b3d5de`](https://github.com/pmatias/python-acquia-cloud-2/commit/1b3d5de1a25fd67cc7bd4486f6ba70a2e3bdad57)
- For code_switch, it can be a branch or a tag. [`ec25ca7`](https://github.com/pmatias/python-acquia-cloud-2/commit/ec25ca7a522a952d682dafb800eb75638d7c79ae)
- Updating CHANGELOG.txt for tag release [`aaf0635`](https://github.com/pmatias/python-acquia-cloud-2/commit/aaf06352bfc8d7073a5e5a30ed7eed8d3424a58b)

## 0.0.1-alpha1 - 2018-05-07

### Commits

- * New resources: Applications, Environments, Subscriptions, Tasks [`a9f498a`](https://github.com/pmatias/python-acquia-cloud-2/commit/a9f498a8837ce5ffccdcfbe7dcbb812edb7431a9)
- Initial unusable version commit to set up some automated services. [`59b5c79`](https://github.com/pmatias/python-acquia-cloud-2/commit/59b5c7951c0c231087d2d4593e3c4c3747a80b5a)
- * Added some of the suggestions posted in #3 [`0937da6`](https://github.com/pmatias/python-acquia-cloud-2/commit/0937da6ce431332046d669304d1357f0375d9d33)
